//=============================================================================
// PLiSHOP.js
//=============================================================================
/*:
 * @plugindesc PLiSHOPでファンディスクを購入しているかを調べます
 * 使い方はヘルプをご覧ください
 * @author PLiCy[プリシー]
 *
 *
 * @help
 * イベントからプラグインコマンドで使用して呼び出します。
 * 取得可能な内容は以下の２つです。
 * －－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－
 * ①プレイヤーが、「特定のファンディスクを購入済みであるか」を確認
 * 　＜コマンド： PLiSHOP https://plicy.net/Shop/Fandisk/X  (Xはファンディスクの番号)＞
 * 
 * ②プレイヤーが、「特定のクリエイターからファンディスクをいくつ購入したか」を確認
 * 　＜コマンド： PLiSHOP http://plicy.net/UserStamp/X　(XはユーザーIDの番号)＞
 * －－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－
 * ※詳しくは、下の【利用方法】をご覧ください。
 * 
 * 
 * 【注意事項】
 * ・ブラウザ上のみで利用可能です。
 * ・テストプレイ/ダウンロード版/アプリ版では動作致しません。
 * ・プレイヤーは使用中のブラウザで、PLiCyにログインをしている必要があります。
 * ・PLiCy以外のWebサーバーでも、プレイヤーがPLiCyにログイン中であれば認証が可能です。
 * ・Webサーバーでプレイをしていない場合、Firefoxであっても利用することはできません。
 * 
 * ・「売上モード」を指定すると購入数が売上額に切り替わります。
 * ・売上額はuniの設定価格に準拠します。
 * 
 * 
 * 【利用方法】－－－－－－－－－－－－－－－－－－－－－－－－－－－
 * 
 * 　＜①プレイヤーが、特定のファンディスクを購入済みであるかを確認＞
 * 
 * フォーマット）
 * 　プラグインコマンドに下記フォーマットで入力をしてください
 * 　『 PLiSHOP https://plicy.net/Shop/Fandisk/X 』
 *  ※「X」にはファンディスクの番号を記入
 * 
 * 実行内容）
 * 　プレイヤーが、上記のファンディスクを購入済みであるかを判別します。
 * 　設定された変数に、結果が代入されます。
 * 
 * 結果）
 * 　購入済みの場合：変数に1を代入（売上モードの場合は価格）
 * 　未購入の場合：変数に0を代入
 * 　ログインをしていない場合：変数に-1を代入
 * 
 * 記入例）
 * 　『 PLiSHOP https://plicy.net/Shop/Fandisk/13 』
 * 　（ファンディスクID：13 の購入/非購入を確認）
 * 　『 PLiSHOP https://plicy.net/Shop/Fandisk/15 』
 * 　（ファンディスクID：15 の購入/非購入を確認）
 * 
 * －－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－
 * 
 * 　＜②プレイヤーが、特定のクリエイターからファンディスクをいくつ購入したかを確認＞
 * 
 * フォーマット）
 * 　プラグインコマンドに下記フォーマットで入力をしてください
 * 　　『 PLiSHOP http://plicy.net/FDUser/X 』
 *  ※「X」にはユーザーIDの番号を記入
 *  
 * 実行内容）
 * 　プレイヤーが、上記のユーザーから購入したファンディスクの数を取得します。
 * 　設定された変数番号に、結果が代入されます。
 * 
 * 結果）
 * 　通常時：変数に購入数を代入（売上モードの場合は売上の合計）
 * 　ログインをしていない場合：変数に-1を代入
 * 
 * 記入例）
 * 　　『 PLiSHOP http://plicy.net/FDUser/1 』
 * 　（クリエイターID:1 が販売しているファンディスクの購入数を確認）
 * 　　『 PLiSHOP http://plicy.net/FDUser/2 』
 * 　（クリエイターID:2 が販売しているファンディスクの購入数を確認）
 * 
 * 
 * 
 * @param Variable
 * @desc 購入数を代入する変数番号の設定をします。
 * 代入先はゲーム中に変更できません。
 * @default 10
 * 
 * @param Earnings mode
 * @desc 売上モードに変更します。
 * 取得される数値が売上額に変わります。（trueで有効）
 * @default false
 * 
 * @param Debug mode
 * @desc 購入数を自由に変更可能にします。（trueで有効）
 * テスト用ですので、公開時にはfalseにしてください。
 * @default false
 */
//============================================================================= 
 
(function() {
    "use strict";
    var parameters,variableID,earningsMode,debugMode,isLoading,interpreterPrototype,isLoading,interpreterPrototype,_interpreterPluginCommand,_interpreterUpdateWaitMode,readStart,loadComplete,fileProtocolSetting,protocol,port,serverHost,clientHost,sendParam;
    parameters = PluginManager.parameters("PLiSHOP");
    variableID = parseInt(parameters["Variable"]);
    earningsMode = parameters["Earnings mode"] === "true" || parameters["Earnings mode"] === true || parameters["Earnings mode"] === "ON";
    debugMode = parameters["Debug mode"] === "true" || parameters["Debug mode"] === true || parameters["Debug mode"] === "ON";
    if(isNaN(variableID)){
        variableID = 10;
    }
    isLoading = false;
    interpreterPrototype = Game_Interpreter.prototype;

    _interpreterPluginCommand = interpreterPrototype.pluginCommand;
    interpreterPrototype.pluginCommand = function(command, args) {
        var url,urlDatas,paramType;
        if (command === "PLiSHOP") {
            url = args[0];
            if(typeof url === "string"){
                urlDatas = url.match(/(https?:\/\/)(plicy.net\/Shop\/Fandisk\/)(\d+)/);
                paramType = 0;
                if(urlDatas){
                    paramType = 1;
                }else{
                    urlDatas = url.match(/(https?:\/\/)(plicy.net\/FDUser\/)(\d+)/);
                    if(urlDatas){
                        paramType = 2;
                    }
                }
                if(paramType !== 0){
                    readStart(paramType,parseInt(urlDatas[3]));
                    this.setWaitMode("PLiSHOP");
                    return false;
                }
            }
            return true;
        }else{
            return _interpreterPluginCommand.call(this, command, args);
        }
    };
    _interpreterUpdateWaitMode = interpreterPrototype.updateWaitMode;
    interpreterPrototype.updateWaitMode = function() {
        if ((this._waitMode === "PLiSHOP") && (isLoading)){
            return true;
        }else{
            return _interpreterUpdateWaitMode.call(this);
        }
    };
    
    protocol = location.protocol;
    port = location.port;
    serverHost = protocol+"//plicy.net/";
    clientHost = protocol+"//"+location.hostname;
    if(port !== ""){
        clientHost += ":" + port;
    }
    sendParam = "host="+encodeURIComponent(clientHost);
    fileProtocolSetting = function(){
        var debugValue,value,str;
        str = "";
        value = -1;
        if(debugMode){
            if(earningsMode){
                str = "設定する売上金額";
            }else{
                str = "設定する購入数";
            }
            Input.clear();
            debugValue = parseInt(window.prompt("現在デバッグモードです。\n"+str+"を入力してください。", value));
            if(isFinite(debugValue)){
                value = debugValue;
            }
        }
        $gameVariables.setValue(variableID,value);
        isLoading = false;
    };
    readStart = function(type,id){
        var url,plicyLoad;
        if(protocol === "file:"){
            fileProtocolSetting();
            return;
        }else{
            url = serverHost + "Shop/Get/"+type+"/"+id;
            isLoading = true;
            plicyLoad = function(){ 
                var xhr;
                xhr = new XMLHttpRequest();
                xhr.open("POST", url, true);
                xhr.onload = loadComplete;
                xhr.onerror = plicyLoad;//reload
                xhr.withCredentials = true;
                xhr.setRequestHeader( "Content-Type", "application/x-www-form-urlencoded" );
                xhr.send(sendParam);
            };
            plicyLoad();
        }
    };
    loadComplete = function(event){
        var value , json , str , xhr;
        xhr = event.target;
        str = xhr.responseText;
        json = null;
        value = 0;
        isLoading = false;
        try{
            json = JSON.parse(str);
        }catch(e){
        }
        if(!json){
            //json error
            value = -1;
        }else{
            try{
                switch(json["Error"]){
                    case 999://login error
                        value = -1;
                    break;
                    case 500://server error
                        value = -1;
                    break;
                    case 403://type error
                        value = -1;
                    break;
                    case 0:
                        if(earningsMode){
                            value = parseInt(json["Earnings"]);
                        }else{
                            value = parseInt(json["Count"]);
                        }
                        if(isNaN(value)){
                            value = -1;//undefined Error
                        }
                    break;
                }
            }catch(e){
                value = -1;
            }
        }
        $gameVariables.setValue(variableID,value);
    };
       
})();